summaryrefslogtreecommitdiffstats
path: root/net/url_request/url_request_job_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/url_request/url_request_job_manager.h')
-rw-r--r--net/url_request/url_request_job_manager.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/net/url_request/url_request_job_manager.h b/net/url_request/url_request_job_manager.h
index 0fbc31e..6d2421a 100644
--- a/net/url_request/url_request_job_manager.h
+++ b/net/url_request/url_request_job_manager.h
@@ -16,14 +16,14 @@
// This class is responsible for managing the set of protocol factories and
// request interceptors that determine how an URLRequestJob gets created to
// handle an URLRequest.
//
// MULTI-THREADING NOTICE:
// URLRequest is designed to have all consumers on a single thread, and so no
// attempt is made to support ProtocolFactory or Interceptor instances being
// registered/unregistered or in any way poked on multiple threads. However,
// we do support checking for supported schemes FROM ANY THREAD (i.e., it is
// safe to call SupportsScheme on any thread).
//
class URLRequestJobManager {
public:
@@ -54,19 +54,19 @@ class URLRequestJobManager {
// Register a protocol factory associated with the given scheme. The factory
// parameter may be null to clear any existing association. Returns the
// previously registered protocol factory if any.
- URLRequest::ProtocolFactory* RegisterProtocolFactory(
- const std::string& scheme, URLRequest::ProtocolFactory* factory);
+ net::URLRequest::ProtocolFactory* RegisterProtocolFactory(
+ const std::string& scheme, net::URLRequest::ProtocolFactory* factory);
// Register/unregister a request interceptor.
- void RegisterRequestInterceptor(URLRequest::Interceptor* interceptor);
- void UnregisterRequestInterceptor(URLRequest::Interceptor* interceptor);
+ void RegisterRequestInterceptor(net::URLRequest::Interceptor* interceptor);
+ void UnregisterRequestInterceptor(net::URLRequest::Interceptor* interceptor);
void set_enable_file_access(bool enable) { enable_file_access_ = enable; }
bool enable_file_access() const { return enable_file_access_; }
private:
- typedef std::map<std::string, URLRequest::ProtocolFactory*> FactoryMap;
- typedef std::vector<URLRequest::Interceptor*> InterceptorList;
+ typedef std::map<std::string, net::URLRequest::ProtocolFactory*> FactoryMap;
+ typedef std::vector<net::URLRequest::Interceptor*> InterceptorList;
mutable Lock lock_;
FactoryMap factories_;
@@ -16,14 +16,14 @@
// This class is responsible for managing the set of protocol factories and
// request interceptors that determine how an URLRequestJob gets created to
-// handle an URLRequest.
+// handle an net::URLRequest.
//
// MULTI-THREADING NOTICE:
@@ -16,14 +16,14 @@
//
// MULTI-THREADING NOTICE:
-// URLRequest is designed to have all consumers on a single thread, and so no
-// attempt is made to support ProtocolFactory or Interceptor instances being
-// registered/unregistered or in any way poked on multiple threads. However,
-// we do support checking for supported schemes FROM ANY THREAD (i.e., it is
-// safe to call SupportsScheme on any thread).
+// net::URLRequest is designed to have all consumers on a single thread, and
+// so no attempt is made to support ProtocolFactory or Interceptor instances
+// being registered/unregistered or in any way poked on multiple threads.
+// However, we do support checking for supported schemes FROM ANY THREAD
+// (i.e., it is safe to call SupportsScheme on any thread).
//
class URLRequestJobManager {